package service.student.studentaddressservice.service;

import org.apache.catalina.valves.StuckThreadDetectionValve;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.stereotype.Repository;
import org.springframework.stereotype.Service;
import service.student.studentaddressservice.StudentAddressServiceApplication;
import service.student.studentaddressservice.exception.ResourceNotFoundException;
import service.student.studentaddressservice.model.StudentAddress;
import service.student.studentaddressservice.repository.StudentAddressRepository;

import java.util.Optional;

@Service
public class StudentAddressService {

    @Autowired
    StudentAddressRepository studentAddressRepository;

    public Optional<StudentAddress> getStudentAddressById(long addressId){
        return studentAddressRepository.findById(addressId);
    }

    public Optional<StudentAddress> getStudentAddressByEmail(String email){
        return Optional.ofNullable(studentAddressRepository.findByEmail(email));
    }

    public StudentAddress createStudentAddress(StudentAddress studentAddressDetails) {
        return studentAddressRepository.save(studentAddressDetails);
    }

    public StudentAddress updateStudentAddress(StudentAddress studentAddressDetails, String email)
            throws ResourceNotFoundException {
        StudentAddress studentAddressToUpdate =
                getStudentAddressByEmail(email).orElseThrow(() -> new ResourceNotFoundException("Email Not found: " + email));
        studentAddressToUpdate.setStreetAddress(studentAddressDetails.getStreetAddress());
        studentAddressToUpdate.setState(studentAddressDetails.getState());
        studentAddressToUpdate.setCity(studentAddressDetails.getCity());
        studentAddressToUpdate.setZip(studentAddressDetails.getZip());
        if (studentAddressDetails.getAptNum() != null) {
            studentAddressToUpdate.setAptNum(studentAddressDetails.getAptNum());
        }
        return studentAddressRepository.save(studentAddressToUpdate);
    }
}
